@@ -1,7 +1,7 @@
 import logging
-from pathlib import Path
 from typing import Callable, Sequence, TypeVar
 
+
 import calcbench as cb
 import pandas as pd
 from tqdm import tqdm
@@ -19,8 +19,11 @@ def iterate_and_save_pandas(
 
     Usage::
 
+    >>> %pip install calcbench-api-client[Pandas,Backoff,tqdm]
+    >>> from calcbench.downloaders import iterate_and_save_pandas
+    >>> import calcbench as cb
     >>> tickers = cb.tickers(entire_universe=True)
-    >>> get_and_save(
+    >>> iterate_and_save_pandas(
     >>>    tickers,
     >>>    lambda ticker: cb.point_in_time(
     >>>        all_face=True,
@@ -30,11 +33,13 @@ def iterate_and_save_pandas(
     >>>        include_preliminary=True,
     >>>        include_xbrl=True,
     >>>    ),
-    >>>    "fact_points.csv",
+    >>>    "face_data.csv",
     >>> )
 
     """
     argument: T
+    write_mode = "w"
+    write_headers = True
     for argument in tqdm(arguments):
         try:
             data = f(argument)
@@ -45,10 +50,11 @@ def iterate_and_save_pandas(
         except Exception as e:
             tqdm.write(f"Exception getting {argument} {e}")
         else:
-            file_exists = Path(file_name).exists()
             data.to_csv(
                 file_name,
-                mode="a" if file_exists else "w",
+                mode=write_mode,
                 index=False,
-                header=not file_exists,
-            )
\ No newline at end of file
+                header=write_headers,
+            )
+            write_mode = "a"
+            write_headers = False
\ No newline at end of file
