@@ -66,6 +66,7 @@ class StandardizedPoint(TypedDict):
     CIK: str
     trace_url: Optional[str]
     period: Any  # pandas period
+    date_reported: str  # only on PIT points
 
 
 def standardized_raw(
@@ -261,7 +262,6 @@ def point_in_time(
     accession_id: int = None,
     include_trace: bool = False,
     set_index: bool = False,
-    exclude_errors: bool = False,
 ) -> "pd.DataFrame":
     """Point-in-Time Data
 
@@ -284,12 +284,18 @@ def point_in_time(
        The value of the fact
     revision_number
        0 indicates an original, unrevised value for this fact. 1, 2, 3... indicates subsequent revisions to the fact value.  https://knowledge.calcbench.com/hc/en-us/search?utf8=%E2%9C%93&query=revisions&commit=Search
+    preliminary
+        True indicates the number was parsed from non-XBRL 8-K or press release from the wire
+    XBRL
+        Indicates the number was parsed from XBRL
     period_start
        First day of the fiscal period for this fact
     period_end
        Last day of the fiscal period for this fact
     date_reported
-       Timestamp when Calcbench published this fact
+       Timestamp when Calcbench published this fact.
+
+       In some cases, particularly prior to 2015, this will be the filing date of the document as recorded by the SEC.  To exclude these points remove points where the hour is 0.
     metric
        The metric name, see the definitions @ https://www.calcbench.com/home/standardizedmetrics
     calendar_year
@@ -340,7 +346,6 @@ def point_in_time(
         accession_id=accession_id,
         include_trace=include_trace,
         include_xbrl=include_xbrl,
-        exclude_errors=exclude_errors,
     )
 
     if not data:
